@@ -90,13 +90,13 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.core
-import constructs
+import aws_cdk.core as _aws_cdk_core_f4b25747
+import constructs as _constructs_77d1e7e8
 
 
-@jsii.implements(aws_cdk.core.IInspectable)
+@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
 class CfnNotificationRule(
-    aws_cdk.core.CfnResource,
+    _aws_cdk_core_f4b25747.CfnResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-codestarnotifications.CfnNotificationRule",
 ):
@@ -137,14 +137,14 @@ class CfnNotificationRule(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: _aws_cdk_core_f4b25747.Construct,
         id: builtins.str,
         *,
         detail_type: builtins.str,
         event_type_ids: typing.Sequence[builtins.str],
         name: builtins.str,
         resource: builtins.str,
-        targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union["CfnNotificationRule.TargetProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]],
+        targets: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[typing.Union["CfnNotificationRule.TargetProperty", typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]]],
         created_by: typing.Optional[builtins.str] = None,
         event_type_id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
@@ -167,23 +167,7 @@ class CfnNotificationRule(
         :param target_address: ``AWS::CodeStarNotifications::NotificationRule.TargetAddress``.
         '''
         if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                detail_type: builtins.str,
-                event_type_ids: typing.Sequence[builtins.str],
-                name: builtins.str,
-                resource: builtins.str,
-                targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]],
-                created_by: typing.Optional[builtins.str] = None,
-                event_type_id: typing.Optional[builtins.str] = None,
-                status: typing.Optional[builtins.str] = None,
-                tags: typing.Any = None,
-                target_address: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__afd9fbc9994fa80bdf60737da78d9f087a32581b7f81c0b4c334c08663e60f9c)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnNotificationRuleProps(
@@ -202,15 +186,13 @@ class CfnNotificationRule(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
-    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
         '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__099a82c08137cec0b43dbe5f7b1d1f05f11dbad5f4403f71ceb6110e60a1fd52)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -223,9 +205,7 @@ class CfnNotificationRule(
         :param props: -
         '''
         if __debug__:
-            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5c3ef9b2c426e96fe677cd4d4414d0a37f3f81ed3db98434f6136136c5935aff)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -250,14 +230,14 @@ class CfnNotificationRule(
 
     @builtins.property
     @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
+    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
         '''A list of tags to apply to this notification rule.
 
         Key names cannot start with " ``aws`` ".
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-tags
         '''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))
 
     @builtins.property
     @jsii.member(jsii_name="detailType")
@@ -273,9 +253,7 @@ class CfnNotificationRule(
     @detail_type.setter
     def detail_type(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1328d7a4da7ac6738932c8452e08a9f4e55096173b2312ae6ab2db86423b1938)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "detailType", value)
 
@@ -293,9 +271,7 @@ class CfnNotificationRule(
     @event_type_ids.setter
     def event_type_ids(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.List[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__473d075788634c1f35d0683a9d9e587ea4f2462911cccfe7dcae793c8ee67be7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeIds", value)
 
@@ -313,9 +289,7 @@ class CfnNotificationRule(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__142bd3ac8c2650fb09979c4507e9dab179ed76b9322f6eaee331ad6ba5770543)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -333,9 +307,7 @@ class CfnNotificationRule(
     @resource.setter
     def resource(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__eeeffb63d38d20cc300c45b3315533d9c340b49c13b122eee8cf79eb6582d934)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resource", value)
 
@@ -343,24 +315,20 @@ class CfnNotificationRule(
     @jsii.member(jsii_name="targets")
     def targets(
         self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", aws_cdk.core.IResolvable]]]:
+    ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _aws_cdk_core_f4b25747.IResolvable]]]:
         '''A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         '''
-        return typing.cast(typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", aws_cdk.core.IResolvable]]], jsii.get(self, "targets"))
+        return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _aws_cdk_core_f4b25747.IResolvable]]], jsii.get(self, "targets"))
 
     @targets.setter
     def targets(
         self,
-        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", aws_cdk.core.IResolvable]]],
+        value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _aws_cdk_core_f4b25747.IResolvable]]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnNotificationRule.TargetProperty, aws_cdk.core.IResolvable]]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a2c95c26691bebee88c7be548c1c6c93065d1b91cf9d25d5b018ba30362271d4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targets", value)
 
@@ -376,9 +344,7 @@ class CfnNotificationRule(
     @created_by.setter
     def created_by(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8ce894a7a6566797118e7e025c8afb3b619760fa0243fbfef148b299b0ee57f0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "createdBy", value)
 
@@ -394,9 +360,7 @@ class CfnNotificationRule(
     @event_type_id.setter
     def event_type_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a3da63eceaa33c3f0096dfc27beda96674cdc9db5157b4588066cea8c8255782)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeId", value)
 
@@ -414,9 +378,7 @@ class CfnNotificationRule(
     @status.setter
     def status(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3ee093cb8a1c33c860df75ca61d85a592b43f62f5d20c2a3ab1c008fccea3e4a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
@@ -432,9 +394,7 @@ class CfnNotificationRule(
     @target_address.setter
     def target_address(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6d9806aa77ce61f06619c13a0820bc0f31ca983daf63d4d3875dde9fc13c4934)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetAddress", value)
 
@@ -470,16 +430,10 @@ class CfnNotificationRule(
                 )
             '''
             if __debug__:
-                def stub(
-                    *,
-                    target_address: builtins.str,
-                    target_type: builtins.str,
-                ) -> None:
-                    ...
-                type_hints = typing.get_type_hints(stub)
+                type_hints = typing.get_type_hints(_typecheckingstub__ed22e756de55f94cf900263f2eaadbfd5bc3bf60675a721cd588d4bd11c7dd08)
                 check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
                 check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
-            self._values: typing.Dict[str, typing.Any] = {
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "target_address": target_address,
                 "target_type": target_type,
             }
@@ -543,7 +497,7 @@ class CfnNotificationRuleProps:
         event_type_ids: typing.Sequence[builtins.str],
         name: builtins.str,
         resource: builtins.str,
-        targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]],
+        targets: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]]],
         created_by: typing.Optional[builtins.str] = None,
         event_type_id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
@@ -593,21 +547,7 @@ class CfnNotificationRuleProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                detail_type: builtins.str,
-                event_type_ids: typing.Sequence[builtins.str],
-                name: builtins.str,
-                resource: builtins.str,
-                targets: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]],
-                created_by: typing.Optional[builtins.str] = None,
-                event_type_id: typing.Optional[builtins.str] = None,
-                status: typing.Optional[builtins.str] = None,
-                tags: typing.Any = None,
-                target_address: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e4eed0a7d017b65718edbd93d2df7bc324716eeff1ff1004d63f607f30a27121)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument event_type_ids", value=event_type_ids, expected_type=type_hints["event_type_ids"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
@@ -618,7 +558,7 @@ class CfnNotificationRuleProps:
             check_type(argname="argument status", value=status, expected_type=type_hints["status"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "detail_type": detail_type,
             "event_type_ids": event_type_ids,
             "name": name,
@@ -687,14 +627,14 @@ class CfnNotificationRuleProps:
     @builtins.property
     def targets(
         self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnNotificationRule.TargetProperty, aws_cdk.core.IResolvable]]]:
+    ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[CfnNotificationRule.TargetProperty, _aws_cdk_core_f4b25747.IResolvable]]]:
         '''A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         '''
         result = self._values.get("targets")
         assert result is not None, "Required property 'targets' is missing"
-        return typing.cast(typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnNotificationRule.TargetProperty, aws_cdk.core.IResolvable]]], result)
+        return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[CfnNotificationRule.TargetProperty, _aws_cdk_core_f4b25747.IResolvable]]], result)
 
     @builtins.property
     def created_by(self) -> typing.Optional[builtins.str]:
@@ -768,7 +708,7 @@ class DetailType(enum.Enum):
 
 
 @jsii.interface(jsii_type="@aws-cdk/aws-codestarnotifications.INotificationRule")
-class INotificationRule(aws_cdk.core.IResource, typing_extensions.Protocol):
+class INotificationRule(_aws_cdk_core_f4b25747.IResource, typing_extensions.Protocol):
     '''Represents a notification rule.'''
 
     @builtins.property
@@ -792,7 +732,7 @@ class INotificationRule(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _INotificationRuleProxy(
-    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_core_f4b25747.IResource), # type: ignore[misc]
 ):
     '''Represents a notification rule.'''
 
@@ -816,9 +756,7 @@ class _INotificationRuleProxy(
         :return: boolean - return true if it had any effect
         '''
         if __debug__:
-            def stub(target: INotificationRuleTarget) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5bf15c00e22ddb8a5e39cc2d68f62dacd02a0df9ef33826beb3c4332246956e4)
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
@@ -833,7 +771,7 @@ class INotificationRuleSource(typing_extensions.Protocol):
     @jsii.member(jsii_name="bindAsNotificationRuleSource")
     def bind_as_notification_rule_source(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleSourceConfig":
         '''Returns a source configuration for notification rule.
 
@@ -850,16 +788,14 @@ class _INotificationRuleSourceProxy:
     @jsii.member(jsii_name="bindAsNotificationRuleSource")
     def bind_as_notification_rule_source(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleSourceConfig":
         '''Returns a source configuration for notification rule.
 
         :param scope: -
         '''
         if __debug__:
-            def stub(scope: constructs.Construct) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__20b8b275f189ccc2ff09accf5dee06390479275c6567082197cd63d48b224308)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleSourceConfig", jsii.invoke(self, "bindAsNotificationRuleSource", [scope]))
 
@@ -874,7 +810,7 @@ class INotificationRuleTarget(typing_extensions.Protocol):
     @jsii.member(jsii_name="bindAsNotificationRuleTarget")
     def bind_as_notification_rule_target(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleTargetConfig":
         '''Returns a target configuration for notification rule.
 
@@ -891,16 +827,14 @@ class _INotificationRuleTargetProxy:
     @jsii.member(jsii_name="bindAsNotificationRuleTarget")
     def bind_as_notification_rule_target(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleTargetConfig":
         '''Returns a target configuration for notification rule.
 
         :param scope: -
         '''
         if __debug__:
-            def stub(scope: constructs.Construct) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3e20c45ecfd9408362a8d96e83c9807ae4314a628594f1a06a45e5a44b35c1dc)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleTargetConfig", jsii.invoke(self, "bindAsNotificationRuleTarget", [scope]))
 
@@ -910,7 +844,7 @@ typing.cast(typing.Any, INotificationRuleTarget).__jsii_proxy_class__ = lambda :
 
 @jsii.implements(INotificationRule)
 class NotificationRule(
-    aws_cdk.core.Resource,
+    _aws_cdk_core_f4b25747.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-codestarnotifications.NotificationRule",
 ):
@@ -948,7 +882,7 @@ class NotificationRule(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[builtins.str],
@@ -969,19 +903,7 @@ class NotificationRule(
         :param notification_rule_name: The name for the notification rule. Notification rule names must be unique in your AWS account. Default: - generated from the ``id``
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                events: typing.Sequence[builtins.str],
-                source: INotificationRuleSource,
-                targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
-                detail_type: typing.Optional[DetailType] = None,
-                enabled: typing.Optional[builtins.bool] = None,
-                notification_rule_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__44cd51cd16c41e58bcfae3942a401921d806a23c62162a792e01a41e083d9b03)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = NotificationRuleProps(
@@ -999,7 +921,7 @@ class NotificationRule(
     @builtins.classmethod
     def from_notification_rule_arn(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         notification_rule_arn: builtins.str,
     ) -> INotificationRule:
@@ -1010,13 +932,7 @@ class NotificationRule(
         :param notification_rule_arn: Notification rule ARN (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                notification_rule_arn: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a06dff87da285389a28eba4fea6cfc17a3a5c96258fa4b30ec7e270c1c834e05)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument notification_rule_arn", value=notification_rule_arn, expected_type=type_hints["notification_rule_arn"])
@@ -1029,9 +945,7 @@ class NotificationRule(
         :param target: The SNS topic or AWS Chatbot Slack target.
         '''
         if __debug__:
-            def stub(target: INotificationRuleTarget) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fb48dc113ab45841e434838dac865b16d7d8da7bea71a773c552204d78f96a19)
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
@@ -1083,18 +997,11 @@ class NotificationRuleOptions:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                detail_type: typing.Optional[DetailType] = None,
-                enabled: typing.Optional[builtins.bool] = None,
-                notification_rule_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f48407bf3ebe283b8c61872ea5e14d9c18182077e17919c837c1bff567b99e10)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
             check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if detail_type is not None:
             self._values["detail_type"] = detail_type
         if enabled is not None:
@@ -1209,24 +1116,14 @@ class NotificationRuleProps(NotificationRuleOptions):
             rule.add_target(slack)
         '''
         if __debug__:
-            def stub(
-                *,
-                detail_type: typing.Optional[DetailType] = None,
-                enabled: typing.Optional[builtins.bool] = None,
-                notification_rule_name: typing.Optional[builtins.str] = None,
-                events: typing.Sequence[builtins.str],
-                source: INotificationRuleSource,
-                targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4ea85023a7f772a61577fd32f2221d993d003fdc427214063f66bfd43ad35823)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
             check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
             check_type(argname="argument events", value=events, expected_type=type_hints["events"])
             check_type(argname="argument source", value=source, expected_type=type_hints["source"])
             check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "events": events,
             "source": source,
         }
@@ -1342,11 +1239,9 @@ class NotificationRuleSourceConfig:
             )
         '''
         if __debug__:
-            def stub(*, source_arn: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fd29f82dfe3e27c5ec57406d9b4dfc765a642065c5b174cc9d45a01196558e1e)
             check_type(argname="argument source_arn", value=source_arn, expected_type=type_hints["source_arn"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "source_arn": source_arn,
         }
 
@@ -1400,16 +1295,10 @@ class NotificationRuleTargetConfig:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                target_address: builtins.str,
-                target_type: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1459d5d9250ba2a6d61e9992954cfd9160ec30c48a4db9956fc9b4b56ad1c2a6)
             check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
             check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "target_address": target_address,
             "target_type": target_type,
         }
@@ -1458,3 +1347,193 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__afd9fbc9994fa80bdf60737da78d9f087a32581b7f81c0b4c334c08663e60f9c(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+    *,
+    detail_type: builtins.str,
+    event_type_ids: typing.Sequence[builtins.str],
+    name: builtins.str,
+    resource: builtins.str,
+    targets: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]]],
+    created_by: typing.Optional[builtins.str] = None,
+    event_type_id: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    tags: typing.Any = None,
+    target_address: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__099a82c08137cec0b43dbe5f7b1d1f05f11dbad5f4403f71ceb6110e60a1fd52(
+    inspector: _aws_cdk_core_f4b25747.TreeInspector,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5c3ef9b2c426e96fe677cd4d4414d0a37f3f81ed3db98434f6136136c5935aff(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1328d7a4da7ac6738932c8452e08a9f4e55096173b2312ae6ab2db86423b1938(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__473d075788634c1f35d0683a9d9e587ea4f2462911cccfe7dcae793c8ee67be7(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__142bd3ac8c2650fb09979c4507e9dab179ed76b9322f6eaee331ad6ba5770543(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eeeffb63d38d20cc300c45b3315533d9c340b49c13b122eee8cf79eb6582d934(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a2c95c26691bebee88c7be548c1c6c93065d1b91cf9d25d5b018ba30362271d4(
+    value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[CfnNotificationRule.TargetProperty, _aws_cdk_core_f4b25747.IResolvable]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8ce894a7a6566797118e7e025c8afb3b619760fa0243fbfef148b299b0ee57f0(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a3da63eceaa33c3f0096dfc27beda96674cdc9db5157b4588066cea8c8255782(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3ee093cb8a1c33c860df75ca61d85a592b43f62f5d20c2a3ab1c008fccea3e4a(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6d9806aa77ce61f06619c13a0820bc0f31ca983daf63d4d3875dde9fc13c4934(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ed22e756de55f94cf900263f2eaadbfd5bc3bf60675a721cd588d4bd11c7dd08(
+    *,
+    target_address: builtins.str,
+    target_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e4eed0a7d017b65718edbd93d2df7bc324716eeff1ff1004d63f607f30a27121(
+    *,
+    detail_type: builtins.str,
+    event_type_ids: typing.Sequence[builtins.str],
+    name: builtins.str,
+    resource: builtins.str,
+    targets: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]]],
+    created_by: typing.Optional[builtins.str] = None,
+    event_type_id: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    tags: typing.Any = None,
+    target_address: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5bf15c00e22ddb8a5e39cc2d68f62dacd02a0df9ef33826beb3c4332246956e4(
+    target: INotificationRuleTarget,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__20b8b275f189ccc2ff09accf5dee06390479275c6567082197cd63d48b224308(
+    scope: _constructs_77d1e7e8.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3e20c45ecfd9408362a8d96e83c9807ae4314a628594f1a06a45e5a44b35c1dc(
+    scope: _constructs_77d1e7e8.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__44cd51cd16c41e58bcfae3942a401921d806a23c62162a792e01a41e083d9b03(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    events: typing.Sequence[builtins.str],
+    source: INotificationRuleSource,
+    targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a06dff87da285389a28eba4fea6cfc17a3a5c96258fa4b30ec7e270c1c834e05(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    notification_rule_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fb48dc113ab45841e434838dac865b16d7d8da7bea71a773c552204d78f96a19(
+    target: INotificationRuleTarget,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f48407bf3ebe283b8c61872ea5e14d9c18182077e17919c837c1bff567b99e10(
+    *,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4ea85023a7f772a61577fd32f2221d993d003fdc427214063f66bfd43ad35823(
+    *,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+    events: typing.Sequence[builtins.str],
+    source: INotificationRuleSource,
+    targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fd29f82dfe3e27c5ec57406d9b4dfc765a642065c5b174cc9d45a01196558e1e(
+    *,
+    source_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1459d5d9250ba2a6d61e9992954cfd9160ec30c48a4db9956fc9b4b56ad1c2a6(
+    *,
+    target_address: builtins.str,
+    target_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
